==> scehomology_1.12.0.tar.gz: scehomology/man/scehomologyLL2HGID.Rd <==
\name{scehomologyLL2HGID}
\alias{scehomologyLL2HGID}
\alias{scehomologyACC2HGID}
\alias{scehomologyHGID2LL}
\alias{scehomologyHGID2ACC} 
\title{Mappings between public database ids and NCBI's Internal
  HomoloGeneIDs for Saccharomyces cerevisiae}  
\description{
  R environments that provides mappings between public database ids and internal
  HomoloGeneIDs (HGID) used by NCBI to represent sequences for
  Saccharomyces cerevisiae. Public database ids include LocusLink ids (LL) and GenBank
  Accesion/RefSeq numbers (ACC).     
}
\details{
  Each R environment provides mapping between either HomoloGeneIds and
  database ids, or the converse. The mapping direction is indicated by
  the name of the environment. For instance, scehomologyACC2HGID provides
  mappings between GenBank accession numbers and HomoloGeneIds.

  For each environment, a given id will map to a named vector of ids,
  the names of which are the NCBI code for that organism.
 
  Mappings contained were based on data provided by HomoloGene.
  
  HomoloGene:\url{ ftp://ftp.ncbi.nih.gov/pub/HomoloGene/old/hmlg.ftp}. Built: HomoloGene built date not available

  Packagebuilt Sun Mar 26 00:44:32 2006
}
\references{
\url{http://www.ncbi.nih.gov/entrez/query.fcgi?db=homologene}
}
\examples{
    require("annotate") || stop("annotate unavailable")
    xx <- as.list(scehomologyLL2HGID)
        if(length(xx) > 5){
                # Get the value of the first key
                xx[2]
                # Get the value for a few keys
                if(length(xx) >= 3){
                        xx[2:4]
                }
        }
}
\keyword{datasets}

==> scehomology_1.14.2.tar.gz: scehomology/man/scehomologyLL2HGID.Rd <==
\name{scehomologyLL2HGID}
\alias{scehomologyLL2HGID}
\alias{scehomologyACC2HGID}
\alias{scehomologyHGID2LL}
\alias{scehomologyHGID2ACC} 
\title{Mappings between public database identifiers and NCBI's Internal
  HomoloGeneIDs for Saccharomyces cerevisiae}  
\description{
  R environments that provides mappings between public database identifiers and internal
  HomoloGeneIDs (HGID) used by NCBI to represent sequences for
  Saccharomyces cerevisiae. Public database identifiers include Entrez Gene identifiers (LL) and GenBank
  Accesion/RefSeq numbers (ACC).     
}
\details{
  Each R environment provides mapping between either HomoloGeneIds and
  database identifiers. or the converse. The mapping direction is indicated by
  the name of the environment. For instance, scehomologyACC2HGID provides
  mappings between GenBank accession numbers and HomoloGeneIds.

  For each environment, a given identifier will map to a named vector of identifiers.
  the names of which are the NCBI code for that organism.
 
  Mappings contained were based on data provided by HomoloGene.
  
  HomoloGene:\\url{ ftp://ftp.ncbi.nih.gov/pub/HomoloGene/old/hmlg.ftp}. Built: HomoloGene built date not available

  Packagebuilt Tue Nov 21 18:37:08 2006
}
\references{
\url{http://www.ncbi.nih.gov/entrez/query.fcgi?db=homologene}
}
\examples{
    require("annotate") || stop("annotate unavailable")
    xx <- as.list(scehomologyLL2HGID)
        if(length(xx) > 5){
                # Get the value of the first key
                xx[2]
                # Get the value for a few keys
                if(length(xx) >= 3){
                        xx[2:4]
                }
        }
}
\keyword{datasets}
